@@ -47,6 +47,7 @@ from sertit.snap import MAX_CORES
 from sertit.vectors import WGS84
 from shapely.geometry import box
 
+from eoreader import utils
 from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
 from eoreader.bands.bands import BandNames
 from eoreader.bands.bands import OpticalBandNames as obn
@@ -461,9 +462,19 @@ class DimapProduct(OpticalProduct):
                 f"You are using a non orthorectified Pleiades product {self.path}, "
                 f"you must provide a valid DEM through the {DEM_PATH} environment variable"
             )
+        else:
+            dem_path = AnyPath(dem_path)
+            if isinstance(dem_path, CloudPath):
+                raise TypeError(
+                    "gdalwarp cannot process DEM stored on cloud with 'RPC_DEM' argument, "
+                    "hence cloud-stored DEM cannot be used with non orthorectified DIMAP data."
+                    f"(DEM: {dem_path}, DIMAP data: {self.name})"
+                )
 
         # Set RPC keywords
         kwargs = {"RPC_DEM": dem_path, "RPC_DEM_MISSING_VALUE": 0}
+        # TODO:  add "refine_gcps" ? With which tolerance ? (ie. '-refine_gcps 500 1.9')
+        #  (https://gdal.org/programs/gdalwarp.html#cmdoption-gdalwarp-refine_gcps)
 
         # Reproject
         # WARNING: may not give correct output resolution
@@ -476,6 +487,7 @@ class DimapProduct(OpticalProduct):
             src_nodata=0,
             dst_nodata=0,  # input data should be in integer
             num_threads=MAX_CORES,
+            resampling=Resampling.bilinear,
             **kwargs,
         )
         # Get dims
@@ -503,7 +515,7 @@ class DimapProduct(OpticalProduct):
 
     def _read_band(
         self,
-        path: str,
+        path: Union[CloudPath, Path],
         band: BandNames = None,
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
@@ -515,7 +527,7 @@ class DimapProduct(OpticalProduct):
             Invalid pixels are not managed here
 
         Args:
-            path (str): Band path
+            path (Union[CloudPath, Path]): Band path
             band (BandNames): Band to read
             resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
@@ -546,7 +558,7 @@ class DimapProduct(OpticalProduct):
                     )
 
                 # Read band
-                band_xda = rasters.read(
+                band_xda = utils.read(
                     reproj_path,
                     resolution=resolution,
                     size=size,
@@ -556,7 +568,7 @@ class DimapProduct(OpticalProduct):
             # Manage the case if we open a simple band (EOReader processed bands)
             elif dst.count == 1:
                 # Read band
-                band_xda = rasters.read(
+                band_xda = utils.read(
                     path,
                     resolution=resolution,
                     size=size,
@@ -566,7 +578,7 @@ class DimapProduct(OpticalProduct):
             # Manage the case if we open a stack (native DIMAP bands)
             else:
                 # Read band
-                band_xda = rasters.read(
+                band_xda = utils.read(
                     path,
                     resolution=resolution,
                     size=size,
@@ -713,32 +725,26 @@ class DimapProduct(OpticalProduct):
             elev_angle = float(center_vals.findtext(".//SUN_ELEVATION"))
             azimuth_angle = float(center_vals.findtext(".//SUN_AZIMUTH"))
         except TypeError:
-            raise InvalidProductError("Azimuth or Zenith angles not found")
+            raise InvalidProductError(
+                "Azimuth or Zenith angles not found in metadata !"
+            )
 
         # From elevation to zenith
         zenith_angle = 90.0 - elev_angle
 
         return azimuth_angle, zenith_angle
 
-    def read_mtd(self) -> (etree._Element, dict):
+    def _read_mtd(self) -> (etree._Element, dict):
         """
         Read metadata and outputs the metadata XML root and its namespaces as a dict
 
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1A_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.read_mtd()
-            (<Element Dimap_Document at 0x1d6d241c608>, {})
-
         Returns:
             (etree._Element, dict): Metadata XML root and its namespaces as a dict
         """
         mtd_from_path = "DIM_*.XML"
         mtd_archived = "DIM_.*\.XML"
 
-        return self._read_mtd(mtd_from_path, mtd_archived)
+        return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
     def _has_cloud_band(self, band: BandNames) -> bool:
         """
@@ -777,14 +783,14 @@ class DimapProduct(OpticalProduct):
 
             with rasterio.open(str(def_utm_path)) as dst:
                 if dst.count > 1:
-                    def_xarr = rasters.read(
+                    def_xarr = utils.read(
                         dst,
                         resolution=resolution,
                         size=size,
                         indexes=[self.band_names[self.get_default_band()]],
                     )
                 else:
-                    def_xarr = rasters.read(dst, resolution=resolution, size=size)
+                    def_xarr = utils.read(dst, resolution=resolution, size=size)
 
                 # Load nodata
                 width = def_xarr.rio.width
@@ -1108,6 +1114,7 @@ class DimapProduct(OpticalProduct):
             )
             meta["transform"] = utm_tr
             meta["crs"] = self.crs()
+            meta["driver"] = "GTiff"
 
             rasters_rio.write(out_arr, meta, reproj_path)
 
