@@ -23,18 +23,21 @@ import tempfile
 import zipfile
 from datetime import datetime
 from enum import unique
+from pathlib import Path
 from typing import Union
 
 import geopandas as gpd
 import numpy as np
 import xarray as xr
+from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio import features, transform
 from rasterio.enums import Resampling
-from sertit import files, rasters, vectors
+from sertit import files, vectors
 from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
 
+from eoreader import utils
 from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
 from eoreader.bands.bands import BandNames
 from eoreader.bands.bands import OpticalBandNames as obn
@@ -105,7 +108,15 @@ class S2Product(OpticalProduct):
         Returns:
             str: Tile name
         """
-        return self.split_name[-2]
+        # Get MTD XML file
+        root, _ = self.read_datatake_mtd()
+
+        # Open identifier
+        try:
+            tile_id = root.findtext(".//PRODUCT_URI")
+        except TypeError:
+            raise InvalidProductError("PRODUCT_URI not found in datatake metadata !")
+        return utils.get_split_name(tile_id)[-2]
 
     def _set_product_type(self) -> None:
         """Set products type"""
@@ -174,6 +185,10 @@ class S2Product(OpticalProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
+        .. WARNING::
+            Sentinel-2 datetime is the datatake sensing time, not the granule sensing time !
+            (the one displayed in the product's name)
+
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
@@ -191,10 +206,23 @@ class S2Product(OpticalProduct):
              Union[str, datetime.datetime]: Its acquisition datetime
         """
 
-        date = self.split_name[2]
+        # Get MTD XML file
+        root, _ = self.read_datatake_mtd()
 
-        if as_datetime:
-            date = datetime.strptime(date, DATETIME_FMT)
+        # Open identifier
+        try:
+            # Sentinel-2 datetime is the datatake sensing time, not the granule sensing time !
+            sensing_time = root.findtext(".//PRODUCT_START_TIME")
+        except TypeError:
+            raise InvalidProductError(
+                "PRODUCT_START_TIME not found in datatake metadata !"
+            )
+
+        # Convert to datetime
+        date = datetime.strptime(sensing_time, "%Y-%m-%dT%H:%M:%S.%fZ")
+
+        if not as_datetime:
+            date = date.strftime(DATETIME_FMT)
 
         return date
 
@@ -314,7 +342,7 @@ class S2Product(OpticalProduct):
 
     def _read_band(
         self,
-        path: str,
+        path: Union[CloudPath, Path],
         band: BandNames = None,
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
@@ -326,7 +354,7 @@ class S2Product(OpticalProduct):
             Invalid pixels are not managed here
 
         Args:
-            path (str): Band path
+            path (Union[CloudPath, Path]): Band path
             band (BandNames): Band to read
             resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
@@ -335,7 +363,7 @@ class S2Product(OpticalProduct):
 
         """
         # Read band
-        band_xda = rasters.read(
+        band_xda = utils.read(
             path, resolution=resolution, size=size, resampling=Resampling.bilinear
         )
 
@@ -533,14 +561,27 @@ class S2Product(OpticalProduct):
 
     def _get_condensed_name(self) -> str:
         """
-        Get S2 products condensed name ({date}_S2_{tile}_{product_type}_{processed_hours}).
+        Get S2 products condensed name ({date}_S2_{tile}_{product_type}_{generation_time}).
 
         Returns:
             str: Condensed name
         """
         # Used to make the difference between 2 products acquired on the same tile at the same date but cut differently
-        proc_time = self.split_name[-1].split("T")[-1]
-        return f"{self.get_datetime()}_{self.platform.name}_{self.tile_name}_{self.product_type.value}_{proc_time}"
+        # Get MTD XML file
+        root, _ = self.read_datatake_mtd()
+
+        # Open identifier
+        try:
+            gen_time = root.findtext(".//GENERATION_TIME")
+        except TypeError:
+            raise InvalidProductError(
+                "GENERATION_TIME not found in datatake metadata !"
+            )
+
+        gen_time = datetime.strptime(gen_time, "%Y-%m-%dT%H:%M:%S.%fZ").strftime(
+            "%H%M%S"
+        )
+        return f"{self.get_datetime()}_{self.platform.name}_{self.tile_name}_{self.product_type.value}_{gen_time}"
 
     def get_mean_sun_angles(self) -> (float, float):
         """
@@ -565,11 +606,13 @@ class S2Product(OpticalProduct):
             zenith_angle = float(mean_sun_angles.findtext("ZENITH_ANGLE"))
             azimuth_angle = float(mean_sun_angles.findtext("AZIMUTH_ANGLE"))
         except TypeError:
-            raise InvalidProductError("Azimuth or Zenith angles not found")
+            raise InvalidProductError(
+                "Azimuth or Zenith angles not found in metadata !"
+            )
 
         return azimuth_angle, zenith_angle
 
-    def read_mtd(self) -> (etree._Element, dict):
+    def _read_mtd(self) -> (etree._Element, dict):
         """
         Read metadata and outputs the metadata XML root and its namespaces as a dict
 
@@ -588,7 +631,29 @@ class S2Product(OpticalProduct):
         mtd_from_path = "GRANULE/*/*.xml"
         mtd_archived = "GRANULE.*\.xml"
 
-        return self._read_mtd(mtd_from_path, mtd_archived)
+        return self._read_mtd_xml(mtd_from_path, mtd_archived)
+
+    def read_datatake_mtd(self) -> (etree._Element, dict):
+        """
+        Read datatake metadata and outputs the metadata XML root and its namespaces as a dict
+        (datatake metadata is the file in the root directory named `MTD_MSI(L1C/L2A).xml`)
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element {https://psd-14.sentinel2.eo.esa.int/PSD/S2_PDI_Level-2A_Tile_Metadata.xsd}Level-2A_Tile_ID at ...>,
+            {'nl': '{https://psd-14.sentinel2.eo.esa.int/PSD/S2_PDI_Level-2A_Tile_Metadata.xsd}'})
+
+        Returns:
+            (etree._Element, dict): Metadata XML root and its namespaces
+        """
+        mtd_from_path = "MTD_MSI*.xml"
+        mtd_archived = "MTD_MSI.*\.xml"
+
+        return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
     def _has_cloud_band(self, band: BandNames) -> bool:
         """
